@@ -3,8 +3,8 @@
 #include <hiredis.h>
 #include <stdbool.h>
 
-SEXP redux_redis_connect(SEXP host, SEXP port);
-SEXP redux_redis_connect_unix(SEXP path);
+SEXP redux_redis_connect(SEXP host, SEXP port, SEXP timeout);
+SEXP redux_redis_connect_unix(SEXP path, SEXP timeout);
 
 SEXP redux_redis_command(SEXP extPtr, SEXP cmd);
 
